@@ -3338,3 +3338,29 @@ String str(Socket& so, strsize_t size)
     String::fix(s);
     return s;
 }
+
+NAMESPACE_UCOMMON
+
+struct sockaddr *_getaddrinfo(struct addrinfo *list)
+{
+    return list->ai_addr;
+}
+
+struct addrinfo *_nextaddrinfo(struct addrinfo *list)
+{
+    if(!list)
+        return NULL;
+
+    return list->ai_next;
+}
+
+socket_t _getaddrsock(struct addrinfo *list)
+{
+    if(!list)
+        return INVALID_SOCKET;
+
+    return ::socket(list->ai_family, list->ai_socktype, list->ai_protocol);
+}
+
+END_NAMESPACE
+
