@@ -39,6 +39,10 @@
 #include <ucommon/platform.h>
 #endif
 
+#ifndef _UCOMMON_GENERICS_H_
+#include <ucommon/generics.h>
+#endif
+
 #ifndef _UCOMMON_PROTOCOLS_H_
 #include <ucommon/protocols.h>
 #endif
@@ -75,7 +79,7 @@ typedef unsigned short strsize_t;
  * manipulate ordinary null terminated character arrays directly in memory.
  * @author David Sugar <dyfet@gnutelephony.org>
  */
-class __EXPORT string : public Object
+class __EXPORT string : public ObjectProtocol
 {
 protected:
     /**
@@ -688,6 +692,13 @@ public:
      */
     string& operator^=(const string& object);
 
+    /**
+     * Concatenate text to an existing string object.
+     * @param text to add.
+     * @return our object for expression use.
+     */
+    string& operator+=(const char *text);
+
     /**
      * Create new cow instance and assign value from null terminated text.
      * @param text to assign from.
@@ -1675,6 +1686,10 @@ inline bool eq(String &s1, String &s2)
  * @param s2 string to compare.
  * @return true if equal.
  */
+inline bool case_eq(char const *s1, char const *s2)
+    {return String::case_equal(s1, s2);}
+
+// to be depreciated...
 inline bool ieq(char const *s1, char const *s2)
     {return String::case_equal(s1, s2);}
 
@@ -1686,6 +1701,9 @@ inline bool ieq(char const *s1, char const *s2)
  * @param size of string to compare.
  * @return true if equal.
  */
+inline bool case_eq(char const *s1, char const *s2, size_t size)
+    {return String::case_equal(s1, s2, size);}
+
 inline bool ieq(char const *s1, char const *s2, size_t size)
     {return String::case_equal(s1, s2, size);}
 
@@ -1722,6 +1740,10 @@ inline String str(double value)
 
 String str(CharacterProtocol& cp, strsize_t size);
 
+template<>
+inline void swap<string_t>(string_t& s1, string_t& s2)
+    {String::swap(s1, s2);}
+
 END_NAMESPACE
 
 #endif
