@@ -17,6 +17,10 @@
 
 #include "local.h"
 
+#ifdef  HAVE_OPENSSL_FIPS_H
+#include <openssl/fips.h>
+#endif
+
 static mutex_t *private_locks = NULL;
 static const char *certid = "generic";
 
@@ -39,6 +43,23 @@ extern "C" {
     }
 }
 
+bool secure::fips(const char *progname)
+{
+#ifdef  HAVE_OPENSSL_FIPS_H
+
+    // must always be first init function called...
+    if(private_locks)
+        return false;
+
+    if(!FIPS_mode_set(1))
+        return false;
+
+    return init(progname);
+#else
+    return false;
+#endif
+}
+
 bool secure::init(const char *progname)
 {
     if(private_locks)
